==> flulm_auth-0.0.1.tar.gz: android/src/main/java/com/awesome/flulm_auth/handler/FluLmResponseHandler.kt <==
/*
 * Copyright (C) 2018 The OpenFlutter Organization
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.awesome.flulm_auth.handler

import com.awesome.flulm_auth.constant.LmPluginKeys
import com.awesomeglobal.paysdk.auth.model.BaseResp
import com.awesomeglobal.paysdk.auth.model.SendAuth
import io.flutter.Log
import io.flutter.plugin.common.MethodChannel

object FluLmResponseHandler {

    private var channel: MethodChannel? = null

    private const val errStr = "errStr"
    private const val errCode = "errCode"
    private const val openId = "openId"
    private const val type = "type"

    fun setMethodChannel(channel: MethodChannel) {
        FluLmResponseHandler.channel = channel
    }


    fun handleResponse(response: BaseResp) {
        when (response) {
            is SendAuth.Resp -> handleAuthResponse(response)
        }
    }


    private fun handleAuthResponse(response: SendAuth.Resp) {
        Log.d("azhansy", "handleAuthResponse=====${response.code}")
        val result = mapOf(
                LmPluginKeys.PLATFORM to LmPluginKeys.ANDROID,
                errCode to response.errCode,
                "code" to response.code,
                "state" to response.state,
                "lang" to response.lang,
                "country" to response.country,
                errStr to response.errStr,
                openId to response.openId,
                "url" to response.url,
                type to response.type
//                LmPluginKeys.TRANSACTION to response.transaction
        )

        channel?.invokeMethod("onAuthResponse", result)
    }

}

==> flulm_auth-0.1.1.tar.gz: android/src/main/java/com/awesome/flulm_auth/handler/FluLmResponseHandler.kt <==
/*
 * Copyright (C) 2018 The OpenFlutter Organization
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.awesome.flulm_auth.handler

import com.awesome.flulm_auth.constant.LmPluginKeys
import com.awesomeglobal.paysdk.auth.model.SendAuth
import com.awesomeglobal.paysdk.modelbase.BaseResp
import io.flutter.Log
import io.flutter.plugin.common.MethodChannel

object FluLmResponseHandler {

    private var channel: MethodChannel? = null

    private const val errStr = "errStr"
    private const val errCode = "errCode"
    private const val openId = "openId"
    private const val type = "type"

    fun setMethodChannel(channel: MethodChannel) {
        FluLmResponseHandler.channel = channel
    }


    fun handleResponse(response: BaseResp) {
        when (response) {
            is SendAuth.Resp -> handleAuthResponse(response)
        }
    }


    private fun handleAuthResponse(response: SendAuth.Resp) {
        Log.d("azhansy", "handleAuthResponse=====${response.code}")
        val result = mapOf(
                LmPluginKeys.PLATFORM to LmPluginKeys.ANDROID,
                errCode to response.errCode,
                "code" to response.code,
                "state" to response.state,
                "lang" to response.lang,
                "country" to response.country,
                errStr to response.errStr,
                openId to response.openId,
                "url" to response.url,
                type to response.type
//                LmPluginKeys.TRANSACTION to response.transaction
        )

        channel?.invokeMethod("onAuthResponse", result)
    }

}
